cloudformation — boto v2.16.0

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.16.0 »
- API Reference »

# cloudformation

## boto.cloudformation

`boto.cloudformation.` `connect_to_region`(region_name, **kw_params)

  Given a valid region name, return a `boto.cloudformation.CloudFormationConnection`.

  Parameters: | region_name (str) – The name of the region to connect to.
  Return type: | `boto.cloudformation.CloudFormationConnection` or `None`
  Returns: | A connection to the given region, or None if an invalid region name is given

`boto.cloudformation.` `regions`()

  Get all available regions for the CloudFormation service.

  Return type: | list
  Returns: | A list of `boto.RegionInfo` instances

## boto.cloudformation.connection

class `boto.cloudformation.connection.` `CloudFormationConnection`(aws_access_key_id=None, aws_secret_access_key=None, is_secure=True, port=None, proxy=None, proxy_port=None, proxy_user=None, proxy_pass=None, debug=0, https_connection_factory=None, region=None, path='/', converter=None, security_token=None, validate_certs=True)

  A Connection to the CloudFormation Service.

  `APIVersion` = '2010-05-15'
  `DefaultRegionEndpoint` = 'cloudformation.us-east-1.amazonaws.com'
  `DefaultRegionName` = 'us-east-1'
  `cancel_update_stack`(stack_name_or_id=None)
  `create_stack`(stack_name, template_body=None, template_url=None, parameters=[], notification_arns=[], disable_rollback=False, timeout_in_minutes=None, capabilities=None, tags=None)

    Creates a CloudFormation Stack as specified by the template.

    Parameters: | stack_name (string) – The name of the Stack, must be unique amoung running Stacks template_body (string) – The template body (JSON string) template_url (string) – An S3 URL of a stored template JSON document. If both the template_body and template_url are specified, the template_body takes precedence parameters (list of tuples) – A list of (key, value) pairs for template input parameters. notification_arns (list of strings) – A list of SNS topics to send Stack event notifications to. disable_rollback (bool) – Indicates whether or not to rollback on failure. timeout_in_minutes (int) – Maximum amount of time to let the Stack spend creating itself. If this timeout is exceeded, the Stack will enter the CREATE_FAILED state. capabilities (list) – The list of capabilities you want to allow in the stack. Currently, the only valid capability is ‘CAPABILITY_IAM’. tags (dict) – A dictionary of (key, value) pairs of tags to associate with this stack.
    Return type: | string
    Returns: | The unique Stack ID.

  `delete_stack`(stack_name_or_id)
  `describe_stack_events`(stack_name_or_id=None, next_token=None)
  `describe_stack_resource`(stack_name_or_id, logical_resource_id)
  `describe_stack_resources`(stack_name_or_id=None, logical_resource_id=None, physical_resource_id=None)
  `describe_stacks`(stack_name_or_id=None)
  `encode_bool`(v)
  `get_template`(stack_name_or_id)
  `list_stack_resources`(stack_name_or_id, next_token=None)
  `list_stacks`(stack_status_filters=[], next_token=None)
  `update_stack`(stack_name, template_body=None, template_url=None, parameters=[], notification_arns=[], disable_rollback=False, timeout_in_minutes=None, capabilities=None, tags=None)

    Updates a CloudFormation Stack as specified by the template.

    Parameters: | stack_name (string) – The name of the Stack, must be unique amoung running Stacks. template_body (string) – The template body (JSON string) template_url (string) – An S3 URL of a stored template JSON document. If both the template_body and template_url are specified, the template_body takes precedence. parameters (list of tuples) – A list of (key, value) pairs for template input parameters. notification_arns (list of strings) – A list of SNS topics to send Stack event notifications to. disable_rollback (bool) – Indicates whether or not to rollback on failure. timeout_in_minutes (int) – Maximum amount of time to let the Stack spend creating itself. If this timeout is exceeded, the Stack will enter the CREATE_FAILED state capabilities (list) – The list of capabilities you want to allow in the stack. Currently, the only valid capability is ‘CAPABILITY_IAM’. tags (dict) – A dictionary of (key, value) pairs of tags to associate with this stack.
    Return type: | string
    Returns: | The unique Stack ID.

  `valid_states` = ('CREATE_IN_PROGRESS', 'CREATE_FAILED', 'CREATE_COMPLETE', 'ROLLBACK_IN_PROGRESS', 'ROLLBACK_FAILED', 'ROLLBACK_COMPLETE', 'DELETE_IN_PROGRESS', 'DELETE_FAILED', 'DELETE_COMPLETE', 'UPDATE_IN_PROGRESS', 'UPDATE_COMPLETE_CLEANUP_IN_PROGRESS', 'UPDATE_COMPLETE', 'UPDATE_ROLLBACK_IN_PROGRESS', 'UPDATE_ROLLBACK_FAILED', 'UPDATE_ROLLBACK_COMPLETE_CLEANUP_IN_PROGRESS', 'UPDATE_ROLLBACK_COMPLETE')
  `validate_template`(template_body=None, template_url=None)

## boto.cloudformation.stack

class `boto.cloudformation.stack.` `Capability`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `NotificationARN`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `Output`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `Parameter`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `Stack`(connection=None)
  `delete`()
  `describe_events`(next_token=None)
  `describe_resource`(logical_resource_id)
  `describe_resources`(logical_resource_id=None, physical_resource_id=None)
  `endElement`(name, value, connection)
  `get_template`()
  `list_resources`(next_token=None)
  `startElement`(name, attrs, connection)
  `update`()

class `boto.cloudformation.stack.` `StackEvent`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)
  `valid_states` = ('CREATE_IN_PROGRESS', 'CREATE_FAILED', 'CREATE_COMPLETE', 'DELETE_IN_PROGRESS', 'DELETE_FAILED', 'DELETE_COMPLETE')

class `boto.cloudformation.stack.` `StackResource`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `StackResourceSummary`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `StackSummary`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.stack.` `Tag`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

## boto.cloudformation.template

class `boto.cloudformation.template.` `Template`(connection=None)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

class `boto.cloudformation.template.` `TemplateParameter`(parent)
  `endElement`(name, value, connection)
  `startElement`(name, attrs, connection)

### Navigation

- index
- modules |
- next |
- previous |
- boto v2.16.0 »
- API Reference »